@@ -4,13 +4,11 @@ class Manager(object):
     # should be re-defined in a subclass
     state_name = None
     object_type = None
-    resource_type = None
 
     def __init__(self, api):
         self.api = api
 
     # shortcuts
-
     @property
     def state(self):
         return self.api.state
@@ -19,6 +17,10 @@ class Manager(object):
     def queue(self):
         return self.api.queue
 
+    @property
+    def token(self):
+        return self.api.token
+
 
 class AllMixin(object):
     def all(self, filt=None):
@@ -26,18 +28,24 @@ class AllMixin(object):
 
 
 class GetByIdMixin(object):
-
     def get_by_id(self, obj_id, only_local=False):
         """
         Finds and returns the object based on its id.
         """
         for obj in self.state[self.state_name]:
-            if obj['id'] == obj_id or obj.temp_id == str(obj_id):
+            if obj["id"] == obj_id or obj.temp_id == str(obj_id):
                 return obj
 
-        if not only_local:
-            getter = getattr(self.api, 'get_%s' % self.object_type)
-            return getter(obj_id)
+        if not only_local and self.object_type is not None:
+            getter = getattr(eval("self.api.%ss" % self.object_type), "get")
+            data = getter(obj_id)
+
+            # retrieves from state, otherwise we return the raw data
+            for obj in self.state[self.state_name]:
+                if obj["id"] == obj_id or obj.temp_id == str(obj_id):
+                    return obj
+
+            return data
 
         return None
 
@@ -46,5 +54,6 @@ class SyncMixin(object):
     """
     Syncs this specific type of objects.
     """
+
     def sync(self):
-        return self.api.sync(resource_types=[self.resource_type])
+        return self.api.sync()
