@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
-from .generic import Manager, AllMixin, SyncMixin
+from .generic import AllMixin, Manager, SyncMixin
 
 
 class LocationsManager(Manager, AllMixin, SyncMixin):
 
-    state_name = 'Locations'
+    state_name = "locations"
     object_type = None  # there is no local state associated
-    resource_type = 'locations'
 
     def clear(self):
         """
         Clears the locations.
         """
         cmd = {
-            'type': 'clear_locations',
-            'uuid': self.api.generate_uuid(),
-            'args': {},
+            "type": "clear_locations",
+            "uuid": self.api.generate_uuid(),
+            "args": {},
         }
         self.queue.append(cmd)
